@@ -124,10 +124,11 @@ for pkg in ${PREREQUISITES}; do
 done
 
 ######################################################################
-# Add specific R packages
+# Add specific R packages - Use sudo for now to system install it.
 ######################################################################
 
-Rscript -e 'devtools::install_github("mlhubber/mlhub")'
+echo -e '\n*** Ensuring mlhub R package is installed - requires admin privileges ...'
+sudo Rscript -e 'devtools::install_github("mlhubber/mlhub", quiet=TRUE)'
 
 ######################################################################
 # Configure bash completion
